@@ -50,9 +50,13 @@ def start_upload(request):
         metadata.get("filename"),
         conf.CACHE_TIMEOUT,
     )
-    cache.add("tus-uploads/{}/file_size".format(resource_id), file_size, conf.CACHE_TIMEOUT)
+    cache.add(
+        "tus-uploads/{}/file_size".format(resource_id), file_size, conf.CACHE_TIMEOUT
+    )
     cache.add("tus-uploads/{}/offset".format(resource_id), 0, conf.CACHE_TIMEOUT)
-    cache.add("tus-uploads/{}/metadata".format(resource_id), metadata, conf.CACHE_TIMEOUT)
+    cache.add(
+        "tus-uploads/{}/metadata".format(resource_id), metadata, conf.CACHE_TIMEOUT
+    )
 
     try:
         with safe_join(get_upload_path(), resource_id).open("wb") as f:
